@@ -44,7 +44,7 @@ module.exports = generators.Base.extend({
         done();
       }.bind(this));
     },
-    askForCompass: function askForAnalytics() {
+    askForAnalytics: function askForAnalytics() {
       var done = this.async();
 
       this.prompt([{
@@ -189,7 +189,7 @@ module.exports = generators.Base.extend({
         this.copy('plugins/com.plugins.flurryLib', 'local_plugins/com.plugins.flurryLib');
         this.plugins.push('local_plugins/com.plugins.flurryLib');
       }
-    }
+    },
 
     installPlugins: function installPlugins() {
       console.log(chalk.yellow('\nInstall plugins registered at plugins.cordova.io: ') + chalk.green('grunt plugin:add:org.apache.cordova.globalization'));
